@@ -15,5 +15,5 @@
 ## You should have received a copy of the GNU General Public License
 ## along with ArboristBridgeR.  If not, see <http://www.gnu.org/licenses/>.
 "Streamline" <-
-"Streamline" <- function(rb)
+"Streamline" <- function(rs)
     UseMethod("Streamline")
