@@ -22,11 +22,13 @@
 #include "ompthread.h"
 
 
-PredictBox::PredictBox(const FramePredict* framePredict_,
+PredictBox::PredictBox(bool oob_,
+                       const FramePredict* framePredict_,
                        const Forest* forest_,
                        const BitMatrix* bag_,
                        LeafFrame* leafFrame_,
                        unsigned int nThread) :
+  oob(oob_),
   framePredict(framePredict_),
   forest(forest_),
   bag(bag_),
@@ -44,31 +46,26 @@ Predict::Predict(const PredictBox* box) :
   forest(box->forest),
   nTree(forest->getNTree()),
   nRow(framePredict->getNRow()),
-  treeOrigin(forest->cacheOrigin()) {
+  treeOrigin(forest->cacheOrigin()),
+  leaf(box->leafFrame),
+  noLeaf(leaf->getNoLeaf()),
+  bag(box->bag),
+  oob(box->oob) {
   predictLeaves = make_unique<unsigned int[]>(rowBlock * nTree);
 }
 
-void Predict::predict(const PredictBox* box) {
+
+void Predict::predict(const PredictBox* box, Quant* quant) {
   auto predict = make_unique<Predict>(box);
-  predict->predictAcross(box->leafFrame, box->bag);
+  predict->predictAcross(quant);
 }
 
 
-unique_ptr<Quant> Predict::predictQuant(const PredictBox* box, const double* quantile, unsigned int nQuant, unsigned int qBin) {
-  auto quant = make_unique<Quant>(static_cast<LeafFrameReg*>(box->leafFrame), box->bag, quantile, nQuant, qBin);
-  auto predict = make_unique<Predict>(box);
-  predict->predictAcross(box->leafFrame, box->bag, quant.get());
-
-  return move(quant);
-}
-
-
-void Predict::predictAcross(LeafFrame* leaf, const BitMatrix *bag, Quant *quant) {
-  noLeaf = leaf->getNoLeaf();
+void Predict::predictAcross(Quant *quant) {
   for (unsigned int rowStart = 0; rowStart < nRow; rowStart += rowBlock) {
     unsigned int rowEnd = min(rowStart + rowBlock, nRow);
     framePredict->transpose(rowStart, rowEnd);
-    predictBlock(rowStart, rowEnd, bag);
+    predictBlock(rowStart, rowEnd);
     leaf->scoreBlock(predictLeaves.get(), rowStart, rowEnd);
     if (quant != nullptr) {
       quant->predictAcross(this, rowStart, rowEnd);
@@ -78,20 +75,18 @@ void Predict::predictAcross(LeafFrame* leaf, const BitMatrix *bag, Quant *quant)
 
 
 void Predict::predictBlock(unsigned int rowStart,
-                           unsigned int rowEnd,
-                           const BitMatrix *bag) {
+                           unsigned int rowEnd) {
   if (framePredict->getNPredFac() == 0)
-    predictBlockNum(rowStart, rowEnd, bag);
+    predictBlockNum(rowStart, rowEnd);
   else if (framePredict->getNPredNum() == 0)
-    predictBlockFac(rowStart, rowEnd, bag);
+    predictBlockFac(rowStart, rowEnd);
   else
-    predictBlockMixed(rowStart, rowEnd, bag);
+    predictBlockMixed(rowStart, rowEnd);
 }
 
 
 void Predict::predictBlockNum(unsigned int rowStart,
-                              unsigned int rowEnd,
-                              const BitMatrix *bag) {
+                              unsigned int rowEnd) {
   OMPBound row;
   OMPBound rowSup = (OMPBound) rowEnd;
 
@@ -99,15 +94,14 @@ void Predict::predictBlockNum(unsigned int rowStart,
   {
 #pragma omp for schedule(dynamic, 1)
     for (row = (OMPBound) rowStart; row < rowSup; row++) {
-      rowNum(row, row - rowStart, forest->getNode(), bag);
+      rowNum(row, row - rowStart, forest->getNode());
     }
   }
 }
 
 
 void Predict::predictBlockFac(unsigned int rowStart,
-                              unsigned int rowEnd,
-                              const BitMatrix *bag) {
+                              unsigned int rowEnd) {
   OMPBound row;
   OMPBound rowSup = (OMPBound) rowEnd;
 
@@ -115,7 +109,7 @@ void Predict::predictBlockFac(unsigned int rowStart,
   {
 #pragma omp for schedule(dynamic, 1)
     for (row = (OMPBound) rowStart; row < rowSup; row++) {
-      rowFac(row, row - rowStart, forest->getNode(), forest->getFacSplit(), bag);
+      rowFac(row, row - rowStart, forest->getNode(), forest->getFacSplit());
   }
   }
 
@@ -123,8 +117,7 @@ void Predict::predictBlockFac(unsigned int rowStart,
 
 
 void Predict::predictBlockMixed(unsigned int rowStart,
-                                unsigned int rowEnd,
-                                const BitMatrix *bag) {
+                                unsigned int rowEnd) {
   OMPBound row;
   OMPBound rowSup = (OMPBound) rowEnd;
 
@@ -132,7 +125,7 @@ void Predict::predictBlockMixed(unsigned int rowStart,
   {
 #pragma omp for schedule(dynamic, 1)
     for (row = (OMPBound) rowStart; row < rowSup; row++) {
-      rowMixed(row, row - rowStart, forest->getNode(), forest->getFacSplit(), bag);
+      rowMixed(row, row - rowStart, forest->getNode(), forest->getFacSplit());
     }
   }
 }
@@ -140,12 +133,11 @@ void Predict::predictBlockMixed(unsigned int rowStart,
 
 void Predict::rowNum(unsigned int row,
                      unsigned int blockRow,
-                     const TreeNode *treeNode,
-                     const class BitMatrix *bag) {
+                     const TreeNode *treeNode) {
   auto rowT = framePredict->baseNum(blockRow);
   for (unsigned int tIdx = 0; tIdx < nTree; tIdx++) {
     auto leafIdx = noLeaf;
-    if (!(bag != nullptr && bag->testBit(tIdx, row))) {
+    if (!(oob && bag->testBit(tIdx, row))) {
       auto idx = treeOrigin[tIdx];
       do {
         idx += treeNode[idx].advance(rowT, leafIdx);
@@ -159,11 +151,10 @@ void Predict::rowNum(unsigned int row,
 void Predict::rowFac(unsigned int row,
                      unsigned int blockRow,
                      const TreeNode *treeNode,
-                     const BVJagged *facSplit,
-                     const BitMatrix *bag) {
+                     const BVJagged *facSplit) {
   for (unsigned int tIdx = 0; tIdx < nTree; tIdx++) {
     auto leafIdx = noLeaf;
-    if (!(bag != nullptr && bag->testBit(tIdx, row))) {
+    if (!(oob && bag->testBit(tIdx, row))) {
       auto rowT = framePredict->baseFac(blockRow);
       auto idx = treeOrigin[tIdx];
       do {
@@ -178,11 +169,10 @@ void Predict::rowFac(unsigned int row,
 void Predict::rowMixed(unsigned int row,
                        unsigned int blockRow,
                        const TreeNode *treeNode,
-                       const BVJagged *facSplit,
-                       const BitMatrix *bag) {
+                       const BVJagged *facSplit) {
   for (unsigned int tIdx = 0; tIdx < nTree; tIdx++) {
     auto leafIdx = noLeaf;
-    if (!(bag != nullptr && bag->testBit(tIdx, row))) {
+    if (!(oob && bag->testBit(tIdx, row))) {
       auto rowNT = framePredict->baseNum(blockRow);
       auto rowFT = framePredict->baseFac(blockRow);
       auto idx = treeOrigin[tIdx];
